@@ -20,11 +20,14 @@ class DownloadItem : public QObject {
 
 signals:
     void statusChanged();
+    void bufferProgress(int percent);
     void progress(int percent);
     void finished();
+    void error(QString);
 
 public:
     DownloadItem(Video *video, QUrl url, QString filename, QObject *parent = 0);
+    ~DownloadItem();
     qint64 bytesTotal() const;
     qint64 bytesReceived() const;
     double remainingTime() const;
@@ -51,9 +54,12 @@ private slots:
     void downloadProgress(qint64 bytesReceived, qint64 bytesTotal);
     void metaDataChanged();
     void requestFinished();
+    void gotStreamUrl(QUrl streamUrl);
+    void speedCheck();
 
 private:
     void init();
+    int initialBufferSize();
 
     qint64 m_bytesReceived;
     QTime m_downloadTime;
@@ -71,6 +77,8 @@ private:
     DownloadItemStatus m_status;
     QString m_errorMessage;
 
+    QTimer *speedCheckTimer;
+
 };
 
 // This is required in order to use QPointer<DownloadItem> as a QVariant
