@@ -3,16 +3,18 @@
 #include "constants.h"
 #include "MainWindow.h"
 #include "searchparams.h"
-#ifdef APP_MAC_STORE
-#include "local/mac/mac_startup.h"
+#ifdef Q_WS_MAC
+#include "mac_startup.h"
+#include "macfullscreen.h"
 #endif
 #ifdef APP_WIN
 #include "local/win/qtwin.h"
 #endif
+#include "iconloader/qticonloader.h"
 
 int main(int argc, char **argv) {
 
-#ifdef APP_MAC_STORE
+#ifdef Q_WS_MAC
     mac::MacMain();
 #endif
 
@@ -20,13 +22,25 @@ int main(int argc, char **argv) {
     if (app.sendMessage("Wake up!"))
         return 0;
 
-    app.setApplicationName(Constants::APP_NAME);
+    app.setApplicationName(Constants::NAME);
     app.setOrganizationName(Constants::ORG_NAME);
     app.setOrganizationDomain(Constants::ORG_DOMAIN);
 #ifndef APP_MAC
     app.setWheelScrollLines(1);
 #endif
 
+#ifdef APP_MAC
+    QFile file(":/mac.css");
+    file.open(QFile::ReadOnly);
+    app.setStyleSheet(QLatin1String(file.readAll()));
+#endif
+
+#ifdef APP_WIN
+    QFile file(":/win.css");
+    file.open(QFile::ReadOnly);
+    app.setStyleSheet(QLatin1String(file.readAll()));
+#endif
+
     const QString locale = QLocale::system().name();
 
     // qt translations
@@ -42,7 +56,7 @@ int main(int argc, char **argv) {
     QString dataDir = "";
 #endif
     QString localeDir = qApp->applicationDirPath() + QDir::separator() + "locale";
-    if (!QFile::exists(localeDir)) {
+    if (!QDir(localeDir).exists()) {
         localeDir = dataDir + QDir::separator() + "locale";
     }
     // qDebug() << "Using locale dir" << localeDir << locale;
@@ -52,20 +66,28 @@ int main(int argc, char **argv) {
     QTextCodec::setCodecForTr(QTextCodec::codecForName("utf8"));
 
     MainWindow mainWin;
-    mainWin.setWindowTitle(Constants::APP_NAME);
+    mainWin.setWindowTitle(Constants::NAME);
+
+#ifdef Q_WS_MAC
+    mac::SetupFullScreenWindow(mainWin.winId());
+#endif
 
 // no window icon on Mac
 #ifndef APP_MAC
-    if (!QFile::exists(dataDir)) {
-        dataDir = qApp->applicationDirPath() + "/data";
-    }
-    const int iconSizes [] = { 16, 22, 24, 32, 48, 64, 128, 256 };
     QIcon appIcon;
-    for (int i = 0; i < 8; i++) {
-        QString size = QString::number(iconSizes[i]);
-        QString png = dataDir + "/" + size + "x" + size + "/minitube.png";
-        // qDebug() << png;
-        appIcon.addFile(png, QSize(iconSizes[i], iconSizes[i]));
+    if (QDir(dataDir).exists()) {
+        appIcon = QtIconLoader::icon(Constants::UNIX_NAME);
+    } else {
+        dataDir = qApp->applicationDirPath() + "/data";
+        const int iconSizes [] = { 16, 22, 32, 48, 64, 128, 256, 512 };
+        for (int i = 0; i < 8; i++) {
+            QString size = QString::number(iconSizes[i]);
+            QString png = dataDir + "/" + size + "x" + size + "/" + Constants::UNIX_NAME + ".png";
+            appIcon.addFile(png, QSize(iconSizes[i], iconSizes[i]));
+        }
+    }
+    if (appIcon.isNull()) {
+        appIcon.addFile(":/images/app.png");
     }
     mainWin.setWindowIcon(appIcon);
 #endif
@@ -92,5 +114,8 @@ int main(int argc, char **argv) {
         mainWin.showMedia(searchParams);
     }
 
+    // Seed random number generator
+    qsrand(QDateTime::currentDateTime().toTime_t());
+
     return app.exec();
 }
